
import java.util.Vector;

import javax.microedition.lcdui.game.Sprite;

/**
 * Entre 2 Almas	[https://sourceforge.net/projects/entre2almas/]  
 * ------------------------------------------------------------------------
 * This file is part of "Entre 2 Almas".
 * "Entre 2 Almas" is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * "Entre 2 Almas" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "Entre 2 Almas"; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * ------------------------------------------------------------------------
 * 		Copyright 2005 - 2006 Pedro Javier Sez Martnez
 * 
 * 
 * Un objeto de tipo Item, formar parte de otro objeto de tipo Escenario.
 * Implementa la interfaz Comparable y Opcionable.
 * 
 * @author Pedro Javier Sez Martnez
 * @version 1.0
 */
public class Item extends Sprite implements Opcionable, Comparable {

	/**
	 * Nombre del Item, el cual ser mostrado cuando el puntero este encima del
	 * Item.
	 */
	String nombre;

	/**
	 * indica si el Item es animado.
	 */
	boolean animado;

	/**
	 * Tiempo que debe transcurrir para que un item animado, cambie a su
	 * siguiente frame.
	 */
	int tmpAnima;

	/**
	 * Sprite que almacena unos frames especiales del Item, como puede ser la
	 * imagen que un objeto tendr en el inventario, o los frames de los
	 * personajes en las conversaciones.
	 */
	String imagenEspecial;

	/**
	 * Array que indica que opciones est o no disponibles
	 */
	public Opcion[] acciones;

	/**
	 * Las posibles combinaciones que este Item tiene con otros items.
	 */
	public AVLTree combinaciones;

	/**
	 * Identificador del Item
	 */
	int id;

	/**
	 * Indica si el Item se vera delante o detrs del personaje principal, es
	 * decir, que si el personaje y el item estn en la misma posicin, este
	 * atributo indica quien se mostrar delante. Y si el Item se ver delante o
	 * detrs del escenario Si posicin vale... - 0 --> El item estar por
	 * detrs del escenario (Objetos no cogibles) - 1 --> El item estar entre
	 * el escenario y el personaje principal - 2 --> El item estar por delante
	 * del personaje principal
	 */
	int posicion;

	/**
	 * Constructor de la clase. Se usa cuando el Item es animado.
	 * 
	 * @param nombre
	 *            Nombre del Item.
	 * @param image
	 *            identificador de Utils que define la imagen que representa
	 *            este Item
	 * @param posX
	 *            posicin X del sprite de este Item
	 * @param posY
	 *            posicin Y del sprite de este Item
	 * @param visible
	 *            indica si el Sprite es visible
	 * @param animado
	 *            indica si el Item es animado.
	 * @param tmpAnima
	 *            Tiempo que debe transcurrir para que un item animado, cambie a
	 *            su siguiente frame.
	 * @param imagenEspecial
	 *            identificador de Utils que define el Sprite especial del Item
	 * @param acciones
	 *            Array que indica que opciones tendr o no disponibles el Item
	 * @param posicion
	 *            Indica como de visible ser el Item
	 * @param id
	 *            identificador que tendr el Item
	 * @param combinable
	 *            Indica si un Item es combinable con otros Items.
	 * @param combinaciones
	 *            Las posibles combinaciones que este Item tiene con otros
	 *            items.
	 */
	public Item(String nombre, String image, int posX, int posY,
			boolean visible, boolean animado, int tmpAnima,
			String imagenEspecial, Vector acciones, int posicion, int id,
			boolean combinable, AVLTree combinaciones) {
		//		cargamos el sprite
		super(Utils.imagen, Utils.anchoIm, Utils.altoIm);
		this.setFrameSequence(Utils.getFrames(image));
		if (Utils.grupo == 1) {//si el grupo es 176x200
			posX = (posX * Utils.aumentaX) / 1000;
			posY = (posY * Utils.aumentaY) / 1000;
		}
		this.setPosition(Utils.inicioPantallaX + posX, Utils.inicioPantallaY
				+ posY);
		this.setVisible(visible);
		this.nombre = nombre;
		//Inicializamos a null las opciones disponibles.
		this.acciones = new Opcion[acciones.size()];
		acciones.copyInto(this.acciones);
		this.animado = animado;
		this.posicion = posicion;
		this.id = id;
		this.tmpAnima = tmpAnima;
		this.imagenEspecial = imagenEspecial;
		if (combinable) {
			this.combinaciones = combinaciones;
		}

	}

	/**
	 * Indica si una determinada accin tiene o no alguna consecuencia
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @return boolean indicando si esa opcin o accin tiene alguna
	 *         consecuencia si es true es que no hay consecuencias, y viceversa.
	 */
	public boolean getConseActivaAcc(int opcionSele) {

		return acciones[opcionSele].consecuencias.isEmpty();
	}

	/**
	 * Establece la consecuencia activa para una determinada accin.
	 * 
	 * @param id
	 *            Identificador de la opcin a modificar.
	 * @param valor
	 *            el nuevo valor de conseActiva
	 */
	public void setConseActivaAcc(String id, int valor) {
		Opcion auxOp = getOpcion(id);
		auxOp.conseActiva = valor;
	}

	/**
	 * Devuelve la consecuencia para una determinada accin
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @return Vector con la consecuencia activa para una determinada accin
	 */
	public Vector getConsecuenciaAcc(int opcionSele) {

		return (Vector) acciones[opcionSele].consecuencias
				.elementAt(acciones[opcionSele].conseActiva);
	}

	/**
	 * El nombre de una determinada accin.
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @return nombre de la accin.
	 */
	public String getNombreAccion(int opcionSele) {
		return acciones[opcionSele].texto;
	}

	/**
	 * Devuelve el numero de acciones disponibles para un Seleccionable
	 * 
	 * @return el numero de acciones disponibles para un Seleccionable
	 */
	public int longAcciones() {
		return acciones.length;
	}

	/**
	 * Establece si una accin esta activa o no
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @param valor
	 *            boolean indicando si est activa o no.
	 */
	public void setAccionActiva(int opcionSele, boolean valor) {
		acciones[opcionSele].activa = valor;
	}

	/**
	 * Indica si una determinada accin esta activa o no.
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @return boolean indicando si la opcin est o no activa.
	 */
	public boolean getAccionActiva(int opcionSele) {
		return acciones[opcionSele].activa;
	}

	/**
	 * Indica si una determinada combinacin tiene o no alguna consecuencia
	 * 
	 * @param indice
	 *            Indice de la combinacin seleccionada en el juego
	 * @return boolean indicando si esa combinacin tiene alguna consecuencia si
	 *         es true es que no hay consecuencias, y viceversa.
	 */
	public boolean getConseActivaCom(int indice) {

		return ((Combinacion) combinaciones.search(indice).data).consecuencias
				.isEmpty();
	}

	/**
	 * Establece la consecuencia activa para una determinada combinacin.
	 * 
	 * @param id
	 *            Id de la combinacin seleccionada en el juego
	 * @param valor
	 *            el nuevo valor de conseActiva
	 */
	public void setConseActivaCom(int id, int valor) {
		((Combinacion) combinaciones.search(id).data).conseActiva = valor;
	}

	/**
	 * Devuelve la consecuencia para una determinada combinacin
	 * 
	 * @param id
	 *            id de la combinacin seleccionada en el juego
	 * @return Vector con la consecuencia activa para una determinada
	 *         combinacin
	 */
	public Vector getConsecuenciaCom(int id) {
		Combinacion aux = (Combinacion) combinaciones.search(id).data;
		return (Vector) aux.consecuencias.elementAt(aux.conseActiva);
	}

	/**
	 * Establece si una combinacin esta activa o no
	 * 
	 * @param id
	 *            Id de la combinacin seleccionada en el juego
	 * @param valor
	 *            boolean indicando si est activa o no.
	 */
	public void setComActiva(int id, boolean valor) {
		((Combinacion) combinaciones.search(id).data).activa = valor;
	}

	/**
	 * Indica si una determinada combinacin esta activa o no.
	 * 
	 * @param id
	 *            Id de la combinacin seleccionada en el juego
	 * @return boolean indicando si la combinacin est o no activa.
	 */
	public boolean getComActiva(int id) {
		return ((Combinacion) combinaciones.search(id).data).activa;
	}

	/**
	 * Devuelve la clave del comparable
	 * 
	 * @return La clave del comparable identificador del comparable.
	 */
	public int getKey() {
		return id;
	}

	/**
	 * Devuelve la opcin cuyo id coincide con el que se pasa como parametro
	 * 
	 * @param id
	 *            String con el identificador de la opcin
	 * @return La opcin cuyo id coincide con el de la opcin.
	 */
	public Opcion getOpcion(String id) {
		for (int i = 0; i < longAcciones(); i++) {
			if (acciones[i] != null) {
				if (acciones[i].id.equals(id)) {
					return acciones[i];
				}
			}
		}
		return null;
	}

}
