
import java.util.Vector;

/**
 * Entre 2 Almas	[https://sourceforge.net/projects/entre2almas/]  
 * ------------------------------------------------------------------------
 * This file is part of "Entre 2 Almas".
 * "Entre 2 Almas" is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * "Entre 2 Almas" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "Entre 2 Almas"; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * ------------------------------------------------------------------------
 * 		Copyright 2005 - 2006 Pedro Javier Sez Martnez
 * 
 * 
 * Aquellas clases cuyos objetos pueden disponer de opciones para mostrar,
 * debern implementar la interfaz Opcionable
 * 
 * @author Pedro Javier Sez Martnez
 * @version 1.0
 */

public interface Opcionable {

	/**
	 * Devuelve la opcin cuyo id coincide con el que se pasa como parmetro
	 * 
	 * @param id
	 *            String con el identificador de la opcin
	 * @return La opcin cuyo id coincide con el de la opcin.
	 */
	public Opcion getOpcion(String id);

	/**
	 * Indica si una determinada accin tiene o no alguna consecuencia
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @return boolean indicando si esa opcin o accin tiene alguna
	 *         consecuencia si es true es que no hay consecuencias, y viceversa.
	 */
	public boolean getConseActivaAcc(int opcionSele);

	/**
	 * Devuelve la consecuencia para una determinada accin
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @return Vector con la consecuencia activa para una determinada accin
	 */
	public Vector getConsecuenciaAcc(int opcionSele);

	/**
	 * Establece la consecuencia activa para una determinada accin.
	 * 
	 * @param id
	 *            Identificador de la opcin a modificar.
	 * @param valor
	 *            el nuevo valor de conseActiva
	 */
	public void setConseActivaAcc(String id, int valor);

	/**
	 * El nombre de una determinada accin.
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @return nombre de la accin.
	 */
	public String getNombreAccion(int opcionSele);

	/**
	 * Devuelve el numero de acciones disponibles para un Seleccionable
	 * 
	 * @return el numero de acciones disponibles para un Seleccionable
	 */
	public int longAcciones();

	/**
	 * Establece si una accin esta activa o no
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @param valor
	 *            boolean indicando si est activa o no.
	 */
	public void setAccionActiva(int opcionSele, boolean valor);

	/**
	 * Indica si una accin esta activa o no
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @return boolean indicando si est activa o no
	 */
	public boolean getAccionActiva(int opcionSele);

}
