
import java.util.Timer;
import javax.microedition.lcdui.*;
import javax.microedition.lcdui.game.Sprite;

/**
 * Entre 2 Almas	[https://sourceforge.net/projects/entre2almas/]  
 * ------------------------------------------------------------------------
 * This file is part of "Entre 2 Almas".
 * "Entre 2 Almas" is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * "Entre 2 Almas" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "Entre 2 Almas"; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * ------------------------------------------------------------------------
 * 		Copyright 2005 - 2006 Pedro Javier Sez Martnez
 * 
 * 
 * La pantalla de presentacin. Hereda de Canvas.
 * 
 * @author Pedro Javier Sez Martnez
 * @version 1.0
 */
public final class SplashScreen extends Canvas {
	/**
	 * Manejador de la pantalla
	 */
	private Display display;

	/**
	 * Objeto con capacidad para ser situado en la pantalla (dysplay), y
	 * representa a lo siguiente que aparecer en la pantalla cuando desaparezca
	 * se quite el splash
	 */
	private Displayable next;

	/**
	 * Controlar el tiempo de ejecucin
	 */
	private Timer timer;

	/**
	 * Sprite que contiene todos los frames del Splash screen
	 */
	private Sprite sprite;

	/**
	 * Tiempo que se ver cada frame del sprite
	 */
	private int dismissTime;

	/**
	 * Numero de frames que tiene el sprite
	 */
	private static int frames;

	/**
	 * Constructor del SplashScreen
	 * 
	 * @param midlet
	 *            Midlet del juego.
	 * @param next
	 *            siguiente pantalla a mostrar una vez que pase el splash
	 * @param dismissTime
	 *            tiempo que se mostrar cada frame
	 */
	public SplashScreen(Entre2Almas midlet, Displayable next, int dismissTime) {
		timer = new Timer();
		this.display = midlet.getDisplay();
		setFullScreenMode(true);
		this.next = next;

		SplashScreen.frames = Utils.getNumFrames(Utils.splash);

		//cargamos los frames del splash screen
		Utils.cargarImagen(Utils.splash);
		sprite = new Sprite(Utils.imagen, Utils.anchoIm, Utils.altoIm);
		sprite.setFrameSequence(Utils.getFrames(Utils.splash));

		this.dismissTime = dismissTime;
		//situamos el frame del sprite en el centro de la pantalla
		sprite.setPosition((getWidth() / 2) - (sprite.getWidth() / 2),
				(getHeight() / 2) - (sprite.getHeight() / 2));
		sprite.setVisible(true);
		//al mostrar este canvas en el dysplay salta el metodo showNotify
		display.setCurrent(this);

	}

	/**
	 * Comprueba si despus de mostrar una imagen del splash, un determinado
	 * tiempo, todava quedan imgenes por mostrar o no
	 * 
	 * @param splashScreen
	 *            el splash screen que estamos mostrando
	 */
	public static void access(SplashScreen splashScreen) {

		if (splashScreen.sprite.getFrame() == frames - 1)
			splashScreen.dismiss();
		else {
			splashScreen.cont();
		}
	}

	/**
	 * Continua mostrando la siguiente imagen que le corresponde al splash
	 * screen
	 */
	private void cont() {
		sprite.nextFrame();
		repaint();
		showNotify();
	}

	/**
	 * Anula el timer que controlaba el tiempo que se mostraba cada splash y
	 * muestra la siguiente pantalla (el men)
	 */
	private void dismiss() {
		timer.cancel();
		setFullScreenMode(false);
		display.setCurrent(next);
	}

	/**
	 * Mtodo llamado cuando una tecla es presionada.
	 */
	protected void keyPressed(int keyCode) {
		dismiss();
	}

	/**
	 * Pinta la pantalla
	 */
	protected void paint(Graphics g) {
		int width = getWidth();
		int height = getHeight();
		g.setColor(0x00FFFFFF); // white
		g.fillRect(0, 0, width, height);
		g.setColor(0x00FF0000); // red
		g.drawRect(1, 1, width - 3, height - 3);

		sprite.paint(g);
	}

	/**
	 * Mtodo llamado si un puntero es pulsado
	 */
	protected void pointerPressed(int x, int y) {
		dismiss();
	}

	/**
	 * Este mtodo salta inmediatamente despus de que el Canvas sea visible en
	 * la pantalla.
	 */
	protected void showNotify() {
		if (dismissTime > 0)
			//schedule har new CountDown(this) cuando pase el tiempo
			// "dimissTime"
			timer.schedule(new CountDown(this), dismissTime);
	}
}